local L = AceLibrary("AceLocale-2.2"):new("Bartender3")

function Bartender3:PopulateOptions()
	self.options = {
		type = "group",
		args = {
			lock = {
				order = 1,
				name = "Lock", 
				type = "toggle",
				desc = "Toggle the lock of the action bars.",
				get = function() return not Bartender3.unlock end,
				set = function(v)
					if Bartender3.unlock then
						Bartender3:Lock()
					else
						Bartender3:Unlock()
					end
				end,
				disabled = function() return InCombatLockdown() end,
			},
			zoom = {
				order = 3,
				name = "Button Zoom",
				type = "toggle",
				desc = "Toggle the Button Zoom",
				get = function() return Bartender3.db.profile.Zoomed end,
				set = function(z)
					Bartender3:SetZoom(z)
				end,
			},
			tooltip = {
				order = 4,
				name = "Button Tooltip",
				type = "toggle",
				desc = "Toggle the Button Tooltip",
				get = function() return not Bartender3.db.profile.HideTooltip end,
				set = function(h)
					Bartender3.db.profile.HideTooltip = not h
				end,
			},
			selfcast = {
				order = 5,
				name = "Self Casting",
				desc = "Configute Self Casting options",
				type = "group",
				args = {
					modifier = {
						order = 1,
						name = "Modifier SelfCast",
						desc = "SelfCast using CTRL/ALT/SHIFT",
						type = "text",
						get = function() return Bartender3.db.profile.SelfCastModifier end,
						set = function(scm)
							Bartender3:SwitchSelfCastModifier(scm)
						end,
						validate = {"ctrl", "alt", "shift", "none"},
					},
					rightclick = {
						order = 2,
						name = "RightClick SelfCast",
						desc = "SelfCast using Right click",
						type = "toggle",
						get = function() return Bartender3.db.profile.SelfCastRightClick end,
						set = function(v)
							Bartender3.db.profile.SelfCastRightClick = v
							for i,v in pairs(Bartender3.actionbars) do
								if v then v:SelfCastUpdate() end
							end
						end,
					},
				},
				disabled = function() return InCombatLockdown() end,
			},
		},
	}
	
	local specialbars = {
		{"bar1", "Bar 1", self.actionbars[1], 1, 0},
		{"bar2", "Bar 2", self.actionbars[2], 2, 0},
		{"bar3", "Bar 3", self.actionbars[3], 3, 0},
		{"bar4", "Bar 4", self.actionbars[4], 4, 0},
		{"bar5", "Bar 5", self.actionbars[5], 5, 0},
		{"bar6", "Bar 6", self.actionbars[6], 6, 0},
		{"bar7", "Bar 7", self.actionbars[7], 7, 0},
		{"bar8", "Bar 8", self.actionbars[8], 8, 0},
		{"bar9", "Bar 9", self.actionbars[9], 9, 0},
		{"bar10", "Bar 10", self.actionbars[10], 10, 0},
		{"stancebar", "Stance Bar", self.specialbars["STANCE"], "STANCE", 1},
		{"petbar", "Pet Bar", self.specialbars["PET"], "PET", 1},
		{"menubar", "Micro Menu Bar", self.specialbars["MICROMENU"], "MICROMENU", 1},
		{"bagbar", "Bag Bar", self.specialbars["BAGS"], "BAGS", 1},
	}
	for i,bar in ipairs(specialbars) do
		local object = bar[3]
		local maxbuttons = object and #object.buttons or self:GetConfig(bar[4], bar[5]).Buttons
		self.options.args[bar[1]] = {
			order = (30+i), 
			name = bar[2],
			type = "group",
			desc = "Configuration for the "..bar[2],
			args = {
				hide = {
					order = 2,
					name = "Hide",
					type = "toggle",
					desc = "Hide the "..bar[2],
					get = function() return self:GetConfig(bar[4], bar[5]).Hide end,
					set = function() object:ToggleVisibilty() end,
					disabled = function() return InCombatLockdown() end,
				},
				rows = {
					order = 4,
					name = "Rows",
					type = "range",
					desc = "Change the rows of the Bar",
					max = maxbuttons, min = 1, step = 1,
					get = function() return self:GetConfig(bar[4], bar[5]).Rows end,
					set = function(r) 
						object:SetRows(r)
					end,
					disabled = function() return InCombatLockdown() or not self:GetConfig(bar[4], bar[5]).Enabled end,
				},
				padding = {
					order = 5,
					name = "Padding",
					type = "range",
					desc = "Padding of the bar.",
					min = -10, max = 30, step = 1,
					get = function() return self:GetConfig(bar[4], bar[5]).Padding end,
					set = function(p)
						object:SetPadding(p)
					end,
					disabled = function() return InCombatLockdown() or not self:GetConfig(bar[4], bar[5]).Enabled end,
				},
				scale = {
					order = 6,
					name = "Scale",
					type = "range",
					desc = "Scale of the bar.",
					min = .1, max = 5, step = 0.05,
					isPercent = true,
					get = function() return self:GetConfig(bar[4], bar[5]).Scale end,
					set = function(s)
						object:SetScale(s)
					end,
					disabled = function() return InCombatLockdown() or not self:GetConfig(bar[4], bar[5]).Enabled end,
				},
				alpha = {
					order = 7,
					name = "Alpha",
					type = "range",
					desc = "Alpha of the bar.",
					min = .1, max = 1,
					get = function() return self:GetConfig(bar[4], bar[5]).Alpha end,
					set = function(a)
						object:SetAlpha(a)
					end,
					disabled = function() return not self:GetConfig(bar[4], bar[5]).Enabled end,
				},
			}
		}
		if i <= 10 then
			self.options.args[bar[1]].args["enabled"] = {
				order = 1,
				name = "Enabled",
				type = "toggle",
				desc = "Enable "..bar[2],
				get = function() return self:GetConfig(bar[4], bar[5]).Rows end,
				set = function() Bartender3:ToggleBarEnabled(i) end,
				disabled = function() return true or InCombatLockdown() end,
			}
		end
	end
	self.options.args["bagbar"].args["keyring"] = {
		order = 10,
		name = "Keyring",
		type = "toggle",
		desc = "Toggle the Keyring",
		get = function() return self:GetConfig("BAGS", 1).Keyring end,
		set = function(a)
			self.specialbars["BAGS"]:ToggleKeyring(a)
		end,
		disabled = function() return InCombatLockdown() or not self:GetConfig("BAGS", 1).Enabled end,
	}
	self.options.args["bagbar"].args["onebag"] = {
		order = 10,
		name = "OneBag",
		type = "toggle",
		desc = "Toggle the display of onle one Bag Icon",
		get = function() return self:GetConfig("BAGS", 1).OneBag end,
		set = function(a)
			self.specialbars["BAGS"]:ToggleOneBag(a)
		end,
		disabled = function() return InCombatLockdown() or not self:GetConfig("BAGS", 1).Enabled end,
	}
	
	self:RegisterChatCommand({ "/bar", "/bartender3", "/bt3" }, self.options )
	self.options.args.standby = nil
end
